@@ -81,8 +81,8 @@ NNS.boost <- function(IVs.train,
 
   if(!is.null(type)){
     type <- tolower(type)
-    if(type=="class"){
-      obj.fn <- expression( mean(predicted == as.numeric(actual)) )
+    if(type == "class" && identical(obj.fn,expression( sum((predicted - actual)^2) ))){
+      obj.fn <- expression(mean( predicted == as.numeric(actual)))
       objective <- "max"
     }
   }
